.. _configuring:

===================
Configuring EC2-API
===================

To configure your EC2API installation, you must define configuration options in these files:

* ``ec2api.conf`` contains EC2API configuration options and resides in the ``/etc/ec2api`` directory.

* ``api-paste.ini`` defines EC2API limits and resides in the ``/etc/ec2api`` directory.

A list of config options based on different topics can be found below:

.. toctree::
   :maxdepth: 1

   api.rst
   metadata.rst
